
# TIF

## Python version
Python 3.8.9

## Dependencies
- Fabric 2: https://www.fabfile.org/
- Docker SDK for Python: https://pypi.org/project/docker/ https://docker-py.readthedocs.io/en/stable/index.html
- Python Hosts: https://pypi.org/project/python-hosts/
- Emoji: https://pypi.org/project/emoji/

## Installation
```bash
pip3 install tif
```
